Module tokio_postgres_impl

Module tokio_postgres_impl 

Structs

PgClient
A wrapper around tokio_postgres::Client implementing the NextSQL Client trait.
PgRow
PgTransaction
A wrapper around tokio_postgres::Transaction implementing the NextSQL Transaction trait. Supports nested transactions (savepoints) and commit/rollback. Drop without calling commit() will rollback the transaction.

Enums

OwnedParam
An owned SQL parameter value. Used internally to convert borrowed &dyn ToSqlParam into owned values that can be moved into async futures.

Functions

convert_params
Convert a slice of borrowed params to a vec of owned params.
to_owned_param
Convert a &dyn ToSqlParam to an owned parameter value by downcasting.