Module tokio_postgres_impl
nextsql_
backend_
rust_
runtime
0.2.0
Module tokio_
postgres_
impl
Module Items
Structs
Enums
Functions
In crate nextsql_
backend_
rust_
runtime
nextsql_backend_rust_runtime
Module
tokio_
postgres_
impl
Structs

PgClient
A wrapper around
tokio_postgres::Client
implementing the NextSQL
Client
trait.
PgRow
PgTransaction
A wrapper around
tokio_postgres::Transaction
implementing the NextSQL
Transaction
trait. Supports nested transactions (savepoints) and commit/rollback. Drop without calling
commit()
will rollback the transaction.
Enums

Owned
Param
An owned SQL parameter value. Used internally to convert borrowed
&dyn ToSqlParam
into owned values that can be moved into async futures.
Functions

convert_
params
Convert a slice of borrowed params to a vec of owned params.
to_
owned_
param
Convert a
&dyn ToSqlParam
to an owned parameter value by downcasting.